## climetlab-power-production
[![PyPI version](https://badge.fury.io/py/climetlab-maelstrom-power-production.svg)](https://badge.fury.io/py/climetlab-maelstrom-power-production)
![workflow](https://github.com/faemmi/climetlab-plugin-a6/actions/workflows/check-and-publish.yml/badge.svg)
[![](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

A dataset plugin for climetlab for the dataset climetlab-plugin-a6/maelstrom-production-forecasts.


Features
--------

In this README is a description of how to get the climetlab-plugin-a6.

## Datasets description

There are three datasets:
- `maelstrom-constants-a-b`
- `maelstrom-power-production`
- `maelstrom-weather-model-level`
- `maelstrom-weather-pressure-level`
- `maelstrom-weather-surface-level`

### `maelstrom-constants-a-b`

#### Usage

```Python
import climetlab as cml
production_data = cml.load_dataset("maelstrom-constants-a-b")
```

#### References
IFS Documentation – Cy47r1, Operational implementation 30 June 2020, Part III: Dynamics and Numerical Procedures, ECMWF, 2020, p. 6, Eq. 2.11

### `maelstrom-power-production`
#### Usage

```Python
import climetlab as cml
production_data = cml.load_dataset("maelstrom-power-production", wea_id="v20508")
```

Currently available WEA IDs:
- `v20508`

### `maelstrom-weather-model-level`
#### Usage

```Python
import climetlab as cml
weather_ml = cml.load_dataset("maelstrom-weather-model-level", date="2019-01-01")
```

Currently available dates:
- `2019-01-01` until `2019-07-31`

### `maelstrom-weather-pressure-level`
#### Usage

```Python
import climetlab as cml
weather_pl = cml.load_dataset("maelstrom-weather-pressure-level", date="2019-01-01")
```

Currently available dates:
- `2019-01-01` until `2019-07-31`

### `maelstrom-weather-surface-level`
#### Usage

```Python
import climetlab as cml
weather_pl = cml.load_dataset("maelstrom-weather-surface-level", date="2019-01-01")
```

Currently available dates:
- `2019-01-01` until `2019-07-31`

## Using climetlab to access the data (supports grib, netcdf and zarr)

See the demo notebooks here (https://github.com/ecmwf-lab/climetlab_climetlab_plugin_a6/notebooks

https://github.com/ecmwf-lab/climetlab_climetlab_plugin_a6/notebooks/demo_maelstrom_production_forecasts.ipynb
[nbviewer] (https://nbviewer.jupyter.org/github/climetlab_climetlab_plugin_a6/blob/main/notebooks/demo_maelstrom_production_forecasts.ipynb)
[colab] (https://colab.research.google.com/github/climetlab_climetlab_plugin_a6/blob/main/notebooks/demo_maelstrom_production_forecasts.ipynb)

The climetlab python package allows easy access to the data with a few lines of code such as:
```Python
!pip install climetlab climetlab_climetlab_plugin_a6
import climetlab as cml
data = cml.load_dataset("maelstrom-power-production", date="2019-01-01")
data.to_xarray()
```
