#!/usr/bin/env python3# (C) Copyright 2021 ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
#
from climetlab.sources import url  # type: ignore

from climetlab_maelstrom_power_production import dataset

PATTERN = "production_data/{wea_id}.nc"


class Production(dataset.AbstractDataset):
    """Access the power production data of a wind plant.

    Parameters
    ----------
    wea_id : str
        Unique ID of the wind plant.

    """

    name = "Wind plant power production dataset"
    documentation = (
        "Contains the power production of wind plants and other measured/reported quantities from each site"
        "(wind speed, rotor speed, regulation by the network operator, and status). "
        "The data is grouped by wind plant."
    )
    url_pattern = PATTERN

    def __init__(self, wea_id: str):
        """Initialize and load the dataset."""
        self.wea_id = wea_id
        self.source = self._get_data()

    def _get_data(self) -> url.Url:
        return self._load_source(wea_id=self.wea_id)
