#!/usr/bin/env python3# (C) Copyright 2021 ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
#
from typing import Union

import xarray as xr

from climetlab_maelstrom_power_production import merger


class WeatherMerger(merger.AbstractMerger):
    """A merger for the weather data."""

    def __init__(self, dimensions: Union[str, list[str]] = None):
        """Initialize the merger."""
        self.concat_dim = dimensions

    def merge(self, paths, **kwargs) -> xr.Dataset:
        """Merge a set of files into a single dataset."""
        return xr.open_mfdataset(
            paths,
            engine=self.engine,
            concat_dim=self.concat_dim,
            combine="by_coords",
            compat="override",
            join="right",
            **kwargs,
        )
