# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['climetlab_maelstrom_power_production',
 'climetlab_maelstrom_power_production.constants',
 'climetlab_maelstrom_power_production.production',
 'climetlab_maelstrom_power_production.weather']

package_data = \
{'': ['*']}

install_requires = \
['climetlab>=0.5.6,<0.6.0']

extras_require = \
{'ci-tests': ['pytest-custom-exit-code>=0.3.0,<0.4.0'],
 'lint': ['black>=20.8b1,<21.0',
          'pyupgrade>=2.20.0,<3.0.0',
          'mypy>=0.910,<0.911']}

entry_points = \
{'climetlab.datasets': ['maelstrom-constants-a-b = '
                        'climetlab_maelstrom_power_production.constants.a_b:ABConstants',
                        'maelstrom-power-production = '
                        'climetlab_maelstrom_power_production.production.production:Production',
                        'maelstrom-weather-model-level = '
                        'climetlab_maelstrom_power_production.weather.model_level:ModelLevelWeather',
                        'maelstrom-weather-pressure-level = '
                        'climetlab_maelstrom_power_production.weather.pressure_level:PressureLevelWeather',
                        'maelstrom-weather-surface-level = '
                        'climetlab_maelstrom_power_production.weather.surface_level:SurfaceLevelWeather']}

setup_kwargs = {
    'name': 'climetlab-maelstrom-power-production',
    'version': '0.1.1',
    'description': 'CliMetLab plugin for the dataset climetlab-plugin-a6/maelstrom-production-forecasts.',
    'long_description': '## climetlab-power-production\n[![PyPI version](https://badge.fury.io/py/climetlab-maelstrom-power-production.svg)](https://badge.fury.io/py/climetlab-maelstrom-power-production)\n![workflow](https://github.com/faemmi/climetlab-plugin-a6/actions/workflows/check-and-publish.yml/badge.svg)\n[![](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\nA dataset plugin for climetlab for the dataset climetlab-plugin-a6/maelstrom-production-forecasts.\n\n\nFeatures\n--------\n\nIn this README is a description of how to get the climetlab-plugin-a6.\n\n## Datasets description\n\nThere are three datasets:\n- `maelstrom-constants-a-b`\n- `maelstrom-power-production`\n- `maelstrom-weather-model-level`\n- `maelstrom-weather-pressure-level`\n- `maelstrom-weather-surface-level`\n\n### `maelstrom-constants-a-b`\n\n#### Usage\n\n```Python\nimport climetlab as cml\nproduction_data = cml.load_dataset("maelstrom-constants-a-b")\n```\n\n#### References\nIFS Documentation – Cy47r1, Operational implementation 30 June 2020, Part III: Dynamics and Numerical Procedures, ECMWF, 2020, p. 6, Eq. 2.11\n\n### `maelstrom-power-production`\n#### Usage\n\n```Python\nimport climetlab as cml\nproduction_data = cml.load_dataset("maelstrom-power-production", wea_id="v20508")\n```\n\nCurrently available WEA IDs:\n- `v20508`\n\n### `maelstrom-weather-model-level`\n#### Usage\n\n```Python\nimport climetlab as cml\nweather_ml = cml.load_dataset("maelstrom-weather-model-level", date="2019-01-01")\n```\n\nCurrently available dates:\n- `2019-01-01` until `2019-07-31`\n\n### `maelstrom-weather-pressure-level`\n#### Usage\n\n```Python\nimport climetlab as cml\nweather_pl = cml.load_dataset("maelstrom-weather-pressure-level", date="2019-01-01")\n```\n\nCurrently available dates:\n- `2019-01-01` until `2019-07-31`\n\n### `maelstrom-weather-surface-level`\n#### Usage\n\n```Python\nimport climetlab as cml\nweather_pl = cml.load_dataset("maelstrom-weather-surface-level", date="2019-01-01")\n```\n\nCurrently available dates:\n- `2019-01-01` until `2019-07-31`\n\n## Using climetlab to access the data (supports grib, netcdf and zarr)\n\nSee the demo notebooks here (https://github.com/ecmwf-lab/climetlab_climetlab_plugin_a6/notebooks\n\nhttps://github.com/ecmwf-lab/climetlab_climetlab_plugin_a6/notebooks/demo_maelstrom_production_forecasts.ipynb\n[nbviewer] (https://nbviewer.jupyter.org/github/climetlab_climetlab_plugin_a6/blob/main/notebooks/demo_maelstrom_production_forecasts.ipynb)\n[colab] (https://colab.research.google.com/github/climetlab_climetlab_plugin_a6/blob/main/notebooks/demo_maelstrom_production_forecasts.ipynb)\n\nThe climetlab python package allows easy access to the data with a few lines of code such as:\n```Python\n!pip install climetlab climetlab_climetlab_plugin_a6\nimport climetlab as cml\ndata = cml.load_dataset("maelstrom-power-production", date="2019-01-01")\ndata.to_xarray()\n```\n',
    'author': 'Fabian Emmerich',
    'author_email': 'fabian.emmerich@4-cast.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://climetlab.readthedocs.io/en/latest/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
